#
# spec file for package gerbv
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gerbv
%define libname lib%{name}
Version:        2.6.1
Release:        13.74
%define somajor 1
Summary:        Gerber File Viewer that supports the RS-274X Standard
License:        GPL-2.0
Group:          Productivity/Scientific/Electronics
Url:            http://gerbv.geda-project.org/
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE gerbv-no-build-time.patch -- fix W: file-contains-date-and-time
Patch1:         gerbv-no-build-time.patch
# PATCH-FIX-UPSTREAM gerbv-2.6.1-no-translation.patch -- disable translation due to missed files
Patch2:         gerbv-2.6.1-no-translation.patch
# PATCH-FIX-UPSTREAM gerbv-fix-install-sh-call.patch -- Fix calling install-sh not from build dir for automake 1.14 
Patch3:         gerbv-fix-install-sh-call.patch
Patch4:         gerbv-2.6.1-undefined-symbols.patch
BuildRequires:  autoconf
BuildRequires:  gtk2-devel
BuildRequires:  libpng-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  po4a
BuildRequires:  update-desktop-files
# Requires:       guile
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Gerber Viewer (gerbv) is a viewer for Gerber files. Gerber files are
generated from PCB CAD system and sent to PCB manufacturers as basis
for the manufacturing process. The standard supported by gerbv is
RS-274X. The basic difference between RS-274D (the old standard) and
RS-274X is basically the addition of apertures in RS-274X. It might be
possible to make an RS-274X file out of an RS-274D file and an
aperture list.

%package -n     %{libname}%{somajor}
Summary:        Gerber File Viewer library
Group:          System/Libraries

%description -n %{libname}%{somajor}
Gerbv library , allows developers to include parsing, editing, exporting,
rendering of Gerber files into other programs.

%package        devel
Summary:        Gerber File Viewer that supports the RS-274X Standard
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{somajor} = %{version}
Requires:       gtk2-devel
Requires:       libpng-devel

%description    devel
This package contains development files for developing applications
that use gerbv library.

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1

%build
./autogen.sh
export LDFLAGS="$LDFLAGS -ldl"
%configure  \
            --disable-static \
            --enable-unit-mm \
            --disable-update-desktop-database

make %{?_smp_mflags}

%install
%make_install
%suse_update_desktop_file -r %{name} Education Engineering
find %{buildroot}%{_libdir} -name '*.la' -type f -delete -print

%post -n %{libname}%{somajor} -p /sbin/ldconfig

%postun -n %{libname}%{somajor} -p /sbin/ldconfig

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc COPYING NEWS README
%{_bindir}/%{name}
%{_mandir}/man1/%{name}*
%{_datadir}/%{name}/
%{_datadir}/icons/*
%{_datadir}/applications/%{name}.desktop

%files -n %{libname}%{somajor}
%defattr(-,root,root)
%{_libdir}/%{libname}.so.%{somajor}*

%files devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/%{libname}.so
%{_libdir}/pkgconfig/%{libname}.pc

%changelog
* Tue Mar  3 2015 dev@stellardeath.org
- Backport commits 55e4460 and dd8f9fa from upstream that cures
  the problem of an undefined symbol "screen" when using gerbv as
  a library
  * gerbv-2.6.1-undefined-symbols.patch
* Tue Mar  3 2015 dmitry_r@opensuse.org
- Fix desktop menu categories
* Tue Oct  7 2014 dmitry_r@opensuse.org
- Fix build with automake 1.14
  * gerbv-fix-install-sh-call.patch
* Tue Jul 23 2013 dmitry_r@opensuse.org
- Update to version 2.6.1
  * Localization support
- Disable localization due to missed files
  * gerbv-2.6.1-no-translation.patch
* Thu Jan  3 2013 dmitry_r@opensuse.org
- Delete guile from requires
- Delete compilation time from binary
  * gerbv-no-build-time.patch
* Wed Dec 26 2012 dmitry_r@opensuse.org
- fix summary
* Tue Dec 25 2012 dmitry_r@opensuse.org
- spec file cleanup
- split libgerbv to separate package
* Tue Dec 27 2011 werner.ho@gmx.de
- new version 2.6.0
* Sat Nov 19 2011 werner.ho@gmx.de
- new version 2.5.0
- build fixes for openSUSE 12.1
* Sat Mar  6 2010 werner.ho@gmx.de
- new version 2.4.0
* Sun Oct 11 2009 werner.ho@gmx.de
- new version 2.3.0
* Fri Feb  6 2009 werner.ho@gmx.de
- new version 2.2.0
* Sat Dec 20 2008 werner.ho@gmx.de
- fixed desktop integration of openSUSE 11.1
- directory fixes
- call /sbin/ldconfig
* Sun Sep 21 2008 werner.ho@gmx.de
- new version 2.1.0
- removed support for older distributions
- created additional devel package
* Mon Mar 24 2008 werner.ho@gmx.de
- fixed desktop integration
* Tue Mar  4 2008 werner.ho@gmx.de
- new version 2.0.1
- desktop integration
* Sun Jan 13 2008 werner.ho@gmx.de
- new version 2.0.0
* Thu Nov 29 2007 werner.ho@gmx.de
- new version 1.0.3
- removed msgstr_size patch
* Wed Feb 28 2007 werner.ho@gmx.de
- added msgstr_size patch
* Tue Aug 29 2006 werner.ho@gmx.de
- added libpng-devel: gkt2-devel of SuSE 9.3 didn't provide it
* Sun Aug 27 2006 werner.ho@gmx.de
- first spec file
